# LunesPy

📦 Library for communication with nodes in mainnet or testnet of the lunes-blockchain network Allows the automation of sending assets, issue end reissue tokens, leasing, registry, and create new wallet.

[![CodeQL](https://github.com/lunes-platform/lunespy/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/lunes-platform/lunespy/actions/workflows/codeql-analysis.yml)
[![Test](https://github.com/lunes-platform/lunespy/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/lunes-platform/lunespy/actions/workflows/test.yml)
![PyPI](https://img.shields.io/pypi/v/lunespy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lunespy)

![PyPI - Downloads](https://img.shields.io/pypi/dm/lunespy)
![GitHub last commit](https://img.shields.io/github/last-commit/lunes-platform/lunespy)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/lunes-platform/lunespy)

![PyPI - License](https://img.shields.io/pypi/l/lunespy)
![Discord](https://img.shields.io/discord/958424925453058158)

---

## Table of Contents

- [Credits](#credits)
- [How to install](#how-to-install)
- [How it works](#how-it-works)
- [Contributing](#contributing)
- [License](#license)

## Credits

[![GitHub Contributors Image](https://contrib.rocks/image?repo=lunes-platform/lunespy)](https://github.com/lunes-platform/lunespy/graphs/contributors)

## How to install

```
pip install lunespy
```

```
poetry add lunespy
```

## How it works

- see the docs: [Telescope](https://lunes-platform.github.io/telescope)

## Contributing

- Before read a code of conduct: **[CODE_OF_CONDUCT](CODE_OF_CONDUCT.md)**
- Follow the guide of development: **[CONTRIBUTING](CONTRIBUTING.md)**

## License

[Apache v2.0](LICENSE)
